summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.gitignore2
-rw-r--r--.zuul.yaml45
-rw-r--r--CONTRIBUTING.rst4
-rw-r--r--README.rst5
-rw-r--r--doc/source/conf.py9
-rw-r--r--doc/source/user/history.rst1
-rw-r--r--doc/source/user/index.rst2
-rw-r--r--doc/source/user/releasenotes.rst6
-rw-r--r--doc/source/user/using.rst2
-rw-r--r--pbr/packaging.py20
-rw-r--r--pbr/tests/test_util.py4
-rw-r--r--pbr/tests/testpackage/setup.cfg4
-rw-r--r--pbr/util.py1
-rw-r--r--playbooks/legacy/pbr-installation-devstack/post.yaml15
-rw-r--r--playbooks/legacy/pbr-installation-devstack/run.yaml136
-rw-r--r--playbooks/legacy/pbr-installation-upstream-devstack/post.yaml15
-rw-r--r--playbooks/legacy/pbr-installation-upstream-devstack/run.yaml136
-rw-r--r--playbooks/pbr-installation-openstack/pre.yaml4
-rw-r--r--playbooks/pbr-installation-openstack/run.yaml6
-rw-r--r--releasenotes/notes/bdist_wininst-removal-4a1c7c3a9f08238d.yaml9
-rw-r--r--releasenotes/source/conf.py15
-rw-r--r--setup.cfg4
-rw-r--r--tools/integration.sh10
-rw-r--r--tox.ini1
24 files changed, 102 insertions, 354 deletions
diff --git a/.gitignore b/.gitignore
index eaebb3e..ac108e4 100644
--- a/.gitignore
+++ b/.gitignore
@@ -9,6 +9,8 @@ doc/source/reference/api/
# Files created by releasenotes build
releasenotes/build
+releasenotes/notes/reno.cache
+RELEASENOTES.rst
# Packages/installer info
*.egg
diff --git a/.zuul.yaml b/.zuul.yaml
index 7605424..a4156aa 100644
--- a/.zuul.yaml
+++ b/.zuul.yaml
@@ -1,12 +1,12 @@
- job:
- name: pbr-installation-devstack-base
- parent: legacy-dsvm-base
- timeout: 7800
+ name: pbr-installation-openstack-base
+ timeout: 5400
+ description: |
+ Base job for pbr jobs that install openstack packages with current
+ pbr. This ensures we don't break our ability to install openstack.
required-projects:
- - openstack/devstack
- - openstack/grenade
+ # TODO update this list with current active python projects
- openstack/pbr
- - openstack/devstack-gate
- openstack/tripleo-ci
- openstack/aodh
- openstack/automaton
@@ -34,7 +34,6 @@
- openstack/manila
- openstack/manila-ui
- openstack/neutron
- - openstack/neutron-fwaas
- openstack/neutron-vpnaas
- openstack/nova
- openstack/octavia
@@ -91,16 +90,20 @@
- openstack/zaqar
- job:
- name: pbr-installation-devstack
- parent: pbr-installation-devstack-base
- run: playbooks/legacy/pbr-installation-devstack/run.yaml
- post-run: playbooks/legacy/pbr-installation-devstack/post.yaml
+ name: pbr-installation-openstack
+ parent: pbr-installation-openstack-base
+ pre-run: playbooks/pbr-installation-openstack/pre.yaml
+ run: playbooks/pbr-installation-openstack/run.yaml
+ vars:
+ pbr_pip_version: ''
- job:
- name: pbr-installation-upstream-devstack
- parent: pbr-installation-devstack-base
- run: playbooks/legacy/pbr-installation-upstream-devstack/run.yaml
- post-run: playbooks/legacy/pbr-installation-upstream-devstack/post.yaml
+ name: pbr-installation-openstack-pip-dev
+ description: |
+ This job runs the pbr installations with pip trunk.
+ parent: pbr-installation-openstack
+ vars:
+ pbr_pip_version: 'git+https://github.com/pypa/pip.git#egg=pip'
- project:
templates:
@@ -114,9 +117,13 @@
- publish-openstack-docs-pti
check:
jobs:
- - pbr-installation-devstack
- - pbr-installation-upstream-devstack
+ - pbr-installation-openstack
+ - pbr-installation-openstack-pip-dev
gate:
jobs:
- - pbr-installation-devstack
- - pbr-installation-upstream-devstack
+ - pbr-installation-openstack
+ - pbr-installation-openstack-pip-dev
+ periodic:
+ jobs:
+ - pbr-installation-openstack
+ - pbr-installation-openstack-pip-dev
diff --git a/CONTRIBUTING.rst b/CONTRIBUTING.rst
index 51b3e69..33adff5 100644
--- a/CONTRIBUTING.rst
+++ b/CONTRIBUTING.rst
@@ -1,13 +1,13 @@
If you would like to contribute to the development of OpenStack,
you must follow the steps in this page:
- http://docs.openstack.org/infra/manual/developers.html
+ https://docs.opendev.org/opendev/infra-manual/latest/developers.html
Once those steps have been completed, changes to OpenStack
should be submitted for review via the Gerrit tool, following
the workflow documented at:
- http://docs.openstack.org/infra/manual/developers.html#development-workflow
+ https://docs.opendev.org/opendev/infra-manual/latest/developers.html#development-workflow
Pull requests submitted through GitHub will be ignored.
diff --git a/README.rst b/README.rst
index 9c1df73..0b6c229 100644
--- a/README.rst
+++ b/README.rst
@@ -32,9 +32,10 @@ them as quickly as possible.
* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/pbr/latest/
-* Source: https://git.openstack.org/cgit/openstack-dev/pbr
+* Source: https://opendev.org/openstack/pbr
* Bugs: https://bugs.launchpad.net/pbr
-* Change Log: https://docs.openstack.org/pbr/latest/user/history.html
+* Release Notes: https://docs.openstack.org/pbr/latest/user/releasenotes.html
+* ChangeLog: https://docs.openstack.org/pbr/latest/user/history.html
.. _d2to1: https://pypi.python.org/pypi/d2to1
.. _distutils2: https://pypi.python.org/pypi/Distutils2
diff --git a/doc/source/conf.py b/doc/source/conf.py
index 13f63a0..aa51538 100644
--- a/doc/source/conf.py
+++ b/doc/source/conf.py
@@ -17,10 +17,17 @@ except ImportError:
openstackdocstheme = None
# openstackdocstheme options
+
+# Deprecated options for docstheme < 2.2.0, can be removed once
+# pbr stops supporting py27.
repository_name = 'openstack/pbr'
bug_project = 'pbr'
bug_tag = ''
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
+# New options with openstackdocstheme >=2.2.0
+openstackdocs_repo_name = 'openstack/pbr'
+openstackdocs_auto_name = False
+openstackdocs_bug_project = 'pbr'
+openstackdocs_bug_tag = ''
# autodoc generation is a bit aggressive and a nuisance when doing heavy
# text edit cycles.
diff --git a/doc/source/user/history.rst b/doc/source/user/history.rst
new file mode 100644
index 0000000..f69be70
--- /dev/null
+++ b/doc/source/user/history.rst
@@ -0,0 +1 @@
+.. include:: ../../../ChangeLog
diff --git a/doc/source/user/index.rst b/doc/source/user/index.rst
index 0629e2e..0c5fec2 100644
--- a/doc/source/user/index.rst
+++ b/doc/source/user/index.rst
@@ -9,3 +9,5 @@
packagers
semver
compatibility
+ releasenotes
+ history
diff --git a/doc/source/user/releasenotes.rst b/doc/source/user/releasenotes.rst
new file mode 100644
index 0000000..6647c66
--- /dev/null
+++ b/doc/source/user/releasenotes.rst
@@ -0,0 +1,6 @@
+===============
+ Release Notes
+===============
+
+.. include:: ../../../RELEASENOTES.rst
+ :start-line: 4
diff --git a/doc/source/user/using.rst b/doc/source/user/using.rst
index 3fa7569..b9659d0 100644
--- a/doc/source/user/using.rst
+++ b/doc/source/user/using.rst
@@ -57,7 +57,7 @@ versions of `setuptools`__. A simple sample can be found in *pbr*'s own
project_urls =
Bug Tracker = https://bugs.launchpad.net/pbr/
Documentation = https://docs.openstack.org/pbr/
- Source Code = https://git.openstack.org/cgit/openstack-dev/pbr/
+ Source Code = https://opendev.org/openstack/pbr
license = Apache-2
classifier =
Development Status :: 4 - Beta
diff --git a/pbr/packaging.py b/pbr/packaging.py
index a697992..90b9933 100644
--- a/pbr/packaging.py
+++ b/pbr/packaging.py
@@ -431,9 +431,9 @@ def generate_script(group, entry_point, header, template):
def override_get_script_args(
- dist, executable=os.path.normpath(sys.executable), is_wininst=False):
+ dist, executable=os.path.normpath(sys.executable)):
"""Override entrypoints console_script."""
- header = easy_install.get_script_header("", executable, is_wininst)
+ header = easy_install.get_script_header("", executable)
for group, template in ENTRY_POINTS_MAP.items():
for name, ep in dist.get_entry_map(group).items():
yield (name, generate_script(group, ep, header, template))
@@ -455,8 +455,12 @@ class LocalInstallScripts(install_scripts.install_scripts):
"""Intercepts console scripts entry_points."""
command_name = 'install_scripts'
- def _make_wsgi_scripts_only(self, dist, executable, is_wininst):
- header = easy_install.get_script_header("", executable, is_wininst)
+ def _make_wsgi_scripts_only(self, dist, executable):
+ # get_script_header() is deprecated since Setuptools 12.0
+ try:
+ header = easy_install.ScriptWriter.get_header("", executable)
+ except AttributeError:
+ header = easy_install.get_script_header("", executable)
wsgi_script_template = ENTRY_POINTS_MAP['wsgi_scripts']
for name, ep in dist.get_entry_map('wsgi_scripts').items():
content = generate_script(
@@ -482,16 +486,12 @@ class LocalInstallScripts(install_scripts.install_scripts):
bs_cmd = self.get_finalized_command('build_scripts')
executable = getattr(
bs_cmd, 'executable', easy_install.sys_executable)
- is_wininst = getattr(
- self.get_finalized_command("bdist_wininst"), '_is_running', False
- )
-
if 'bdist_wheel' in self.distribution.have_run:
# We're building a wheel which has no way of generating mod_wsgi
# scripts for us. Let's build them.
# NOTE(sigmavirus24): This needs to happen here because, as the
# comment below indicates, no_ep is True when building a wheel.
- self._make_wsgi_scripts_only(dist, executable, is_wininst)
+ self._make_wsgi_scripts_only(dist, executable)
if self.no_ep:
# no_ep is True if we're installing into an .egg file or building
@@ -505,7 +505,7 @@ class LocalInstallScripts(install_scripts.install_scripts):
get_script_args = easy_install.get_script_args
executable = '"%s"' % executable
- for args in get_script_args(dist, executable, is_wininst):
+ for args in get_script_args(dist, executable):
self.write_script(*args)
diff --git a/pbr/tests/test_util.py b/pbr/tests/test_util.py
index a9fdf6e..0a02fc1 100644
--- a/pbr/tests/test_util.py
+++ b/pbr/tests/test_util.py
@@ -103,12 +103,12 @@ class TestMapFieldsParsingScenarios(base.BaseTestCase):
project_urls =
Bug Tracker = https://bugs.launchpad.net/pbr/
Documentation = https://docs.openstack.org/pbr/
- Source Code = https://git.openstack.org/cgit/openstack-dev/pbr/
+ Source Code = https://opendev.org/openstack/pbr
""", # noqa: E501
'expected_project_urls': {
'Bug Tracker': 'https://bugs.launchpad.net/pbr/',
'Documentation': 'https://docs.openstack.org/pbr/',
- 'Source Code': 'https://git.openstack.org/cgit/openstack-dev/pbr/', # noqa: E501
+ 'Source Code': 'https://opendev.org/openstack/pbr',
},
}),
('query_parameters', {
diff --git a/pbr/tests/testpackage/setup.cfg b/pbr/tests/testpackage/setup.cfg
index 3929f0d..e323252 100644
--- a/pbr/tests/testpackage/setup.cfg
+++ b/pbr/tests/testpackage/setup.cfg
@@ -9,13 +9,13 @@ home-page = http://pypi.python.org/pypi/pbr
project_urls =
Bug Tracker = https://bugs.launchpad.net/pbr/
Documentation = https://docs.openstack.org/pbr/
- Source Code = https://git.openstack.org/cgit/openstack-dev/pbr/
+ Source Code = https://opendev.org/openstack/pbr
summary = Test package for testing pbr
description-file =
README.txt
CHANGES.txt
description-content-type = text/plain; charset=UTF-8
-requires-python = >=2.5
+python-requires = >=2.5
requires-dist =
setuptools
diff --git a/pbr/util.py b/pbr/util.py
index 60b7cd7..89f5088 100644
--- a/pbr/util.py
+++ b/pbr/util.py
@@ -114,6 +114,7 @@ D1_D2_SETUP_ARGS = {
"install_requires": ("metadata", "requires_dist"),
"setup_requires": ("metadata", "setup_requires_dist"),
"python_requires": ("metadata",),
+ "requires_python": ("metadata", "python_requires"),
"provides": ("metadata", "provides_dist"), # **
"provides_extras": ("metadata",),
"obsoletes": ("metadata", "obsoletes_dist"), # **
diff --git a/playbooks/legacy/pbr-installation-devstack/post.yaml b/playbooks/legacy/pbr-installation-devstack/post.yaml
deleted file mode 100644
index e07f551..0000000
--- a/playbooks/legacy/pbr-installation-devstack/post.yaml
+++ /dev/null
@@ -1,15 +0,0 @@
-- hosts: primary
- tasks:
-
- - name: Copy files from {{ ansible_user_dir }}/workspace/ on node
- synchronize:
- src: '{{ ansible_user_dir }}/workspace/'
- dest: '{{ zuul.executor.log_root }}'
- mode: pull
- copy_links: true
- verify_host: true
- rsync_opts:
- - --include=/logs/**
- - --include=*/
- - --exclude=*
- - --prune-empty-dirs
diff --git a/playbooks/legacy/pbr-installation-devstack/run.yaml b/playbooks/legacy/pbr-installation-devstack/run.yaml
deleted file mode 100644
index 96f863a..0000000
--- a/playbooks/legacy/pbr-installation-devstack/run.yaml
+++ /dev/null
@@ -1,136 +0,0 @@
-- hosts: all
- name: Autoconverted job legacy-pbr-installation-dsvm from old job gate-pbr-installation-dsvm-ubuntu-xenial
- tasks:
-
- - name: Ensure legacy workspace directory
- file:
- path: '{{ ansible_user_dir }}/workspace'
- state: directory
-
- - shell:
- cmd: |
- set -e
- set -x
- cat > clonemap.yaml << EOF
- clonemap:
- - name: openstack/devstack-gate
- dest: devstack-gate
- EOF
- /usr/zuul-env/bin/zuul-cloner -m clonemap.yaml --cache-dir /opt/git \
- https://opendev.org \
- openstack/devstack-gate
- executable: /bin/bash
- chdir: '{{ ansible_user_dir }}/workspace'
- environment: '{{ zuul | zuul_legacy_vars }}'
-
- - shell:
- cmd: |
- set -e
- set -x
- # Define the entire projects list here so that what we
- # test requirements against is independent of what d-g
- # thinks is relevant.
- export PROJECTS="openstack/devstack-gate $PROJECTS"
- export PROJECTS="openstack/devstack $PROJECTS"
- export PROJECTS="openstack/grenade $PROJECTS"
- export PROJECTS="openstack/pbr $PROJECTS"
- export PROJECTS="openstack/tripleo-ci $PROJECTS"
- export PROJECTS="openstack/aodh $PROJECTS"
- export PROJECTS="openstack/automaton $PROJECTS"
- export PROJECTS="openstack/ceilometer $PROJECTS"
- export PROJECTS="openstack/ceilometermiddleware $PROJECTS"
- export PROJECTS="openstack/cinder $PROJECTS"
- export PROJECTS="openstack/cliff $PROJECTS"
- export PROJECTS="openstack/debtcollector $PROJECTS"
- export PROJECTS="openstack/dib-utils $PROJECTS"
- export PROJECTS="openstack/diskimage-builder $PROJECTS"
- export PROJECTS="openstack/django_openstack_auth $PROJECTS"
- export PROJECTS="openstack/futurist $PROJECTS"
- export PROJECTS="openstack/glance $PROJECTS"
- export PROJECTS="openstack/glance_store $PROJECTS"
- export PROJECTS="openstack/heat $PROJECTS"
- export PROJECTS="openstack/heat-cfntools $PROJECTS"
- export PROJECTS="openstack/heat-templates $PROJECTS"
- export PROJECTS="openstack/horizon $PROJECTS"
- export PROJECTS="openstack/ironic $PROJECTS"
- export PROJECTS="openstack/ironic-lib $PROJECTS"
- export PROJECTS="openstack/ironic-python-agent $PROJECTS"
- export PROJECTS="openstack/keystone $PROJECTS"
- export PROJECTS="openstack/keystoneauth $PROJECTS"
- export PROJECTS="openstack/keystonemiddleware $PROJECTS"
- export PROJECTS="openstack/manila $PROJECTS"
- export PROJECTS="openstack/manila-ui $PROJECTS"
- export PROJECTS="openstack/zaqar $PROJECTS"
- export PROJECTS="openstack/neutron $PROJECTS"
- export PROJECTS="openstack/neutron-fwaas $PROJECTS"
- export PROJECTS="openstack/octavia $PROJECTS"
- export PROJECTS="openstack/neutron-vpnaas $PROJECTS"
- export PROJECTS="openstack/nova $PROJECTS"
- export PROJECTS="openstack/os-apply-config $PROJECTS"
- export PROJECTS="openstack/os-brick $PROJECTS"
- export PROJECTS="openstack/os-client-config $PROJECTS"
- export PROJECTS="openstack/os-collect-config $PROJECTS"
- export PROJECTS="openstack/os-net-config $PROJECTS"
- export PROJECTS="openstack/os-refresh-config $PROJECTS"
- export PROJECTS="openstack/osc-lib $PROJECTS"
- export PROJECTS="openstack/oslo.cache $PROJECTS"
- export PROJECTS="openstack/oslo.concurrency $PROJECTS"
- export PROJECTS="openstack/oslo.config $PROJECTS"
- export PROJECTS="openstack/oslo.context $PROJECTS"
- export PROJECTS="openstack/oslo.db $PROJECTS"
- export PROJECTS="openstack/oslo.i18n $PROJECTS"
- export PROJECTS="openstack/oslo.log $PROJECTS"
- export PROJECTS="openstack/oslo.messaging $PROJECTS"
- export PROJECTS="openstack/oslo.middleware $PROJECTS"
- export PROJECTS="openstack/oslo.policy $PROJECTS"
- export PROJECTS="openstack/oslo.reports $PROJECTS"
- export PROJECTS="openstack/oslo.rootwrap $PROJECTS"
- export PROJECTS="openstack/oslo.utils $PROJECTS"
- export PROJECTS="openstack/oslo.serialization $PROJECTS"
- export PROJECTS="openstack/oslo.service $PROJECTS"
- export PROJECTS="openstack/oslo.versionedobjects $PROJECTS"
- export PROJECTS="openstack/oslo.vmware $PROJECTS"
- export PROJECTS="openstack/pycadf $PROJECTS"
- export PROJECTS="openstack/python-cinderclient $PROJECTS"
- export PROJECTS="openstack/python-glanceclient $PROJECTS"
- export PROJECTS="openstack/python-heatclient $PROJECTS"
- export PROJECTS="openstack/python-ironicclient $PROJECTS"
- export PROJECTS="openstack/python-keystoneclient $PROJECTS"
- export PROJECTS="openstack/python-manilaclient $PROJECTS"
- export PROJECTS="openstack/python-zaqarclient $PROJECTS"
- export PROJECTS="openstack/python-neutronclient $PROJECTS"
- export PROJECTS="openstack/python-novaclient $PROJECTS"
- export PROJECTS="openstack/python-openstackclient $PROJECTS"
- export PROJECTS="openstack/python-saharaclient $PROJECTS"
- export PROJECTS="openstack/python-swiftclient $PROJECTS"
- export PROJECTS="openstack/python-troveclient $PROJECTS"
- export PROJECTS="openstack/requirements $PROJECTS"
- export PROJECTS="openstack/sahara $PROJECTS"
- export PROJECTS="openstack/sahara-dashboard $PROJECTS"
- export PROJECTS="openstack/stevedore $PROJECTS"
- export PROJECTS="openstack/swift $PROJECTS"
- export PROJECTS="openstack/taskflow $PROJECTS"
- export PROJECTS="openstack/tempest $PROJECTS"
- export PROJECTS="openstack/tooz $PROJECTS"
- export PROJECTS="openstack/tripleo-heat-templates $PROJECTS"
- export PROJECTS="openstack/tripleo-image-elements $PROJECTS"
- export PROJECTS="openstack/trove $PROJECTS"
- export PROJECTS="openstack/trove-dashboard $PROJECTS"
- export PYTHONUNBUFFERED=true
- export DEVSTACK_GATE_TEMPEST=0
- export DEVSTACK_GATE_EXERCISES=0
- export DEVSTACK_GATE_REQS_INTEGRATION=1
- export PIP_PROCESS_DEPENDENCY_LINKS=1
- if [ "" = "-upstream" ]; then
- export PBR_PIP_VERSION=git+https://github.com/pypa/pip.git#egg=pip
- fi
- function gate_hook {
- set -x
- bash -xe $BASE/new/pbr/tools/integration.sh $(cat $BASE/new/requirements/projects.txt)
- }
- export -f gate_hook
- cp devstack-gate/devstack-vm-gate-wrap.sh ./safe-devstack-vm-gate-wrap.sh
- ./safe-devstack-vm-gate-wrap.sh
- executable: /bin/bash
- chdir: '{{ ansible_user_dir }}/workspace'
- environment: '{{ zuul | zuul_legacy_vars }}'
diff --git a/playbooks/legacy/pbr-installation-upstream-devstack/post.yaml b/playbooks/legacy/pbr-installation-upstream-devstack/post.yaml
deleted file mode 100644
index e07f551..0000000
--- a/playbooks/legacy/pbr-installation-upstream-devstack/post.yaml
+++ /dev/null
@@ -1,15 +0,0 @@
-- hosts: primary
- tasks:
-
- - name: Copy files from {{ ansible_user_dir }}/workspace/ on node
- synchronize:
- src: '{{ ansible_user_dir }}/workspace/'
- dest: '{{ zuul.executor.log_root }}'
- mode: pull
- copy_links: true
- verify_host: true
- rsync_opts:
- - --include=/logs/**
- - --include=*/
- - --exclude=*
- - --prune-empty-dirs
diff --git a/playbooks/legacy/pbr-installation-upstream-devstack/run.yaml b/playbooks/legacy/pbr-installation-upstream-devstack/run.yaml
deleted file mode 100644
index 544dd43..0000000
--- a/playbooks/legacy/pbr-installation-upstream-devstack/run.yaml
+++ /dev/null
@@ -1,136 +0,0 @@
-- hosts: all
- name: Autoconverted job legacy-pbr-installation-dsvm-upstream from old job gate-pbr-installation-dsvm-upstream-ubuntu-xenial
- tasks:
-
- - name: Ensure legacy workspace directory
- file:
- path: '{{ ansible_user_dir }}/workspace'
- state: directory
-
- - shell:
- cmd: |
- set -e
- set -x
- cat > clonemap.yaml << EOF
- clonemap:
- - name: openstack/devstack-gate
- dest: devstack-gate
- EOF
- /usr/zuul-env/bin/zuul-cloner -m clonemap.yaml --cache-dir /opt/git \
- https://opendev.org \
- openstack/devstack-gate
- executable: /bin/bash
- chdir: '{{ ansible_user_dir }}/workspace'
- environment: '{{ zuul | zuul_legacy_vars }}'
-
- - shell:
- cmd: |
- set -e
- set -x
- # Define the entire projects list here so that what we
- # test requirements against is independent of what d-g
- # thinks is relevant.
- export PROJECTS="openstack/devstack-gate $PROJECTS"
- export PROJECTS="openstack/devstack $PROJECTS"
- export PROJECTS="openstack/grenade $PROJECTS"
- export PROJECTS="openstack/pbr $PROJECTS"
- export PROJECTS="openstack/tripleo-ci $PROJECTS"
- export PROJECTS="openstack/aodh $PROJECTS"
- export PROJECTS="openstack/automaton $PROJECTS"
- export PROJECTS="openstack/ceilometer $PROJECTS"
- export PROJECTS="openstack/ceilometermiddleware $PROJECTS"
- export PROJECTS="openstack/cinder $PROJECTS"
- export PROJECTS="openstack/cliff $PROJECTS"
- export PROJECTS="openstack/debtcollector $PROJECTS"
- export PROJECTS="openstack/dib-utils $PROJECTS"
- export PROJECTS="openstack/diskimage-builder $PROJECTS"
- export PROJECTS="openstack/django_openstack_auth $PROJECTS"
- export PROJECTS="openstack/futurist $PROJECTS"
- export PROJECTS="openstack/glance $PROJECTS"
- export PROJECTS="openstack/glance_store $PROJECTS"
- export PROJECTS="openstack/heat $PROJECTS"
- export PROJECTS="openstack/heat-cfntools $PROJECTS"
- export PROJECTS="openstack/heat-templates $PROJECTS"
- export PROJECTS="openstack/horizon $PROJECTS"
- export PROJECTS="openstack/ironic $PROJECTS"
- export PROJECTS="openstack/ironic-lib $PROJECTS"
- export PROJECTS="openstack/ironic-python-agent $PROJECTS"
- export PROJECTS="openstack/keystone $PROJECTS"
- export PROJECTS="openstack/keystoneauth $PROJECTS"
- export PROJECTS="openstack/keystonemiddleware $PROJECTS"
- export PROJECTS="openstack/manila $PROJECTS"
- export PROJECTS="openstack/manila-ui $PROJECTS"
- export PROJECTS="openstack/zaqar $PROJECTS"
- export PROJECTS="openstack/neutron $PROJECTS"
- export PROJECTS="openstack/neutron-fwaas $PROJECTS"
- export PROJECTS="openstack/octavia $PROJECTS"
- export PROJECTS="openstack/neutron-vpnaas $PROJECTS"
- export PROJECTS="openstack/nova $PROJECTS"
- export PROJECTS="openstack/os-apply-config $PROJECTS"
- export PROJECTS="openstack/os-brick $PROJECTS"
- export PROJECTS="openstack/os-client-config $PROJECTS"
- export PROJECTS="openstack/os-collect-config $PROJECTS"
- export PROJECTS="openstack/os-net-config $PROJECTS"
- export PROJECTS="openstack/os-refresh-config $PROJECTS"
- export PROJECTS="openstack/osc-lib $PROJECTS"
- export PROJECTS="openstack/oslo.cache $PROJECTS"
- export PROJECTS="openstack/oslo.concurrency $PROJECTS"
- export PROJECTS="openstack/oslo.config $PROJECTS"
- export PROJECTS="openstack/oslo.context $PROJECTS"
- export PROJECTS="openstack/oslo.db $PROJECTS"
- export PROJECTS="openstack/oslo.i18n $PROJECTS"
- export PROJECTS="openstack/oslo.log $PROJECTS"
- export PROJECTS="openstack/oslo.messaging $PROJECTS"
- export PROJECTS="openstack/oslo.middleware $PROJECTS"
- export PROJECTS="openstack/oslo.policy $PROJECTS"
- export PROJECTS="openstack/oslo.reports $PROJECTS"
- export PROJECTS="openstack/oslo.rootwrap $PROJECTS"
- export PROJECTS="openstack/oslo.utils $PROJECTS"
- export PROJECTS="openstack/oslo.serialization $PROJECTS"
- export PROJECTS="openstack/oslo.service $PROJECTS"
- export PROJECTS="openstack/oslo.versionedobjects $PROJECTS"
- export PROJECTS="openstack/oslo.vmware $PROJECTS"
- export PROJECTS="openstack/pycadf $PROJECTS"
- export PROJECTS="openstack/python-cinderclient $PROJECTS"
- export PROJECTS="openstack/python-glanceclient $PROJECTS"
- export PROJECTS="openstack/python-heatclient $PROJECTS"
- export PROJECTS="openstack/python-ironicclient $PROJECTS"
- export PROJECTS="openstack/python-keystoneclient $PROJECTS"
- export PROJECTS="openstack/python-manilaclient $PROJECTS"
- export PROJECTS="openstack/python-zaqarclient $PROJECTS"
- export PROJECTS="openstack/python-neutronclient $PROJECTS"
- export PROJECTS="openstack/python-novaclient $PROJECTS"
- export PROJECTS="openstack/python-openstackclient $PROJECTS"
- export PROJECTS="openstack/python-saharaclient $PROJECTS"
- export PROJECTS="openstack/python-swiftclient $PROJECTS"
- export PROJECTS="openstack/python-troveclient $PROJECTS"
- export PROJECTS="openstack/requirements $PROJECTS"
- export PROJECTS="openstack/sahara $PROJECTS"
- export PROJECTS="openstack/sahara-dashboard $PROJECTS"
- export PROJECTS="openstack/stevedore $PROJECTS"
- export PROJECTS="openstack/swift $PROJECTS"
- export PROJECTS="openstack/taskflow $PROJECTS"
- export PROJECTS="openstack/tempest $PROJECTS"
- export PROJECTS="openstack/tooz $PROJECTS"
- export PROJECTS="openstack/tripleo-heat-templates $PROJECTS"
- export PROJECTS="openstack/tripleo-image-elements $PROJECTS"
- export PROJECTS="openstack/trove $PROJECTS"
- export PROJECTS="openstack/trove-dashboard $PROJECTS"
- export PYTHONUNBUFFERED=true
- export DEVSTACK_GATE_TEMPEST=0
- export DEVSTACK_GATE_EXERCISES=0
- export DEVSTACK_GATE_REQS_INTEGRATION=1
- export PIP_PROCESS_DEPENDENCY_LINKS=1
- if [ "-upstream" = "-upstream" ]; then
- export PBR_PIP_VERSION=git+https://github.com/pypa/pip.git#egg=pip
- fi
- function gate_hook {
- set -x
- bash -xe $BASE/new/pbr/tools/integration.sh $(cat $BASE/new/requirements/projects.txt)
- }
- export -f gate_hook
- cp devstack-gate/devstack-vm-gate-wrap.sh ./safe-devstack-vm-gate-wrap.sh
- ./safe-devstack-vm-gate-wrap.sh
- executable: /bin/bash
- chdir: '{{ ansible_user_dir }}/workspace'
- environment: '{{ zuul | zuul_legacy_vars }}'
diff --git a/playbooks/pbr-installation-openstack/pre.yaml b/playbooks/pbr-installation-openstack/pre.yaml
new file mode 100644
index 0000000..4737f6a
--- /dev/null
+++ b/playbooks/pbr-installation-openstack/pre.yaml
@@ -0,0 +1,4 @@
+- hosts: all
+ roles:
+ - ensure-pip
+ - ensure-virtualenv
diff --git a/playbooks/pbr-installation-openstack/run.yaml b/playbooks/pbr-installation-openstack/run.yaml
new file mode 100644
index 0000000..adf7665
--- /dev/null
+++ b/playbooks/pbr-installation-openstack/run.yaml
@@ -0,0 +1,6 @@
+- hosts: all
+ tasks:
+ - shell:
+ cmd: |
+ export PBR_PIP_VERSION="{{ pbr_pip_version }}"
+ bash -xe /home/zuul/src/opendev.org/openstack/pbr/tools/integration.sh $(cat /home/zuul/src/opendev.org/openstack/requirements/projects.txt)
diff --git a/releasenotes/notes/bdist_wininst-removal-4a1c7c3a9f08238d.yaml b/releasenotes/notes/bdist_wininst-removal-4a1c7c3a9f08238d.yaml
new file mode 100644
index 0000000..c3e9410
--- /dev/null
+++ b/releasenotes/notes/bdist_wininst-removal-4a1c7c3a9f08238d.yaml
@@ -0,0 +1,9 @@
+---
+other:
+ - |
+ Support to generate bdist_wininst packages has been removed. As of Python
+ 3.8 and Setuptools 47.2 it's deprecated in favor of just using wheels for
+ Windows platform packaging. See
+ https://discuss.python.org/t/deprecate-bdist-wininst/ and
+ https://discuss.python.org/t/remove-distutils-bdist-wininst-command/ for
+ more details.
diff --git a/releasenotes/source/conf.py b/releasenotes/source/conf.py
index 56f7ecd..0c3627c 100644
--- a/releasenotes/source/conf.py
+++ b/releasenotes/source/conf.py
@@ -41,13 +41,16 @@ release = ''
# a list of builtin themes.
html_theme = 'openstackdocs'
-# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
-# using the given strftime format.
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
-
# -- Options for openstackdocstheme ---------------------------------------
-repository_name = 'openstack-dev/pbr'
+# Deprecated options for openstackdocstheme < 2.2.0, can be removed once
+# pbr stops supporting py27.
+repository_name = 'openstack/pbr'
bug_project = 'pbr'
bug_tag = ''
+
+# New options with openstackdocstheme >=2.2.0
+openstackdocs_repo_name = 'openstack/pbr'
+openstackdocs_auto_name = False
+openstackdocs_bug_project = 'pbr'
+openstackdocs_bug_tag = ''
diff --git a/setup.cfg b/setup.cfg
index 31d0f5c..97fcfea 100644
--- a/setup.cfg
+++ b/setup.cfg
@@ -10,8 +10,8 @@ home-page = https://docs.openstack.org/pbr/latest/
project_urls =
Bug Tracker = https://bugs.launchpad.net/pbr/
Documentation = https://docs.openstack.org/pbr/
- Source Code = https://git.openstack.org/cgit/openstack-dev/pbr/
-requires-python = >=2.6
+ Source Code = https://opendev.org/openstack/pbr
+python-requires = >=2.6
classifier =
Development Status :: 5 - Production/Stable
Environment :: Console
diff --git a/tox.ini b/tox.ini
index 70f2127..7bc530a 100644
--- a/tox.ini
+++ b/tox.ini
@@ -26,6 +26,7 @@ deps =
-r{toxinidir}/doc/requirements.txt
commands =
rm -rf doc/build doc/source/reference/api
+ python setup.py sdist
sphinx-build -W -b html doc/source doc/build/html {posargs}
[testenv:releasenotes]
diff --git a/tools/integration.sh b/tools/integration.sh
index ff337ef..566fc50 100644
--- a/tools/integration.sh
+++ b/tools/integration.sh
@@ -13,7 +13,7 @@ function mkvenv {
venv=$1
rm -rf $venv
- virtualenv $venv
+ virtualenv -p python3 $venv
$venv/bin/pip install $PIPFLAGS -U $PIPVERSION wheel requests
# If a change to PBR is being tested, preinstall the wheel for it
@@ -22,11 +22,11 @@ function mkvenv {
fi
}
# BASE should be a directory with a subdir called "new" and in that
# dir, there should be a git repository for every entry in PROJECTS
-BASE=${BASE:-/opt/stack}
+BASE=${BASE:-/home/zuul/src/opendev.org/}
-REPODIR=${REPODIR:-$BASE/new}
+REPODIR=${REPODIR:-$BASE/openstack}
# TODO: Figure out how to get this on to the box properly
sudo apt-get update
@@ -160,7 +160,7 @@ export PBRVERSION
export PROJECTS
export REPODIR
export WHEELHOUSE
-export OS_TEST_TIMEOUT=600
+export OS_TEST_TIMEOUT=900
cd $REPODIR/pbr
mkvenv .venv
source .venv/bin/activate
@@ -22,11 +22,11 @@ function mkvenv {
fi
}
-# BASE should be a directory with a subdir called "new" and in that
+# BASE should be a directory with a subdir called "openstack" and in that
# dir, there should be a git repository for every entry in PROJECTS